@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 """
-    :copyright: Copyright 2013 by Łukasz Mierzwa
+    :copyright: Copyright 2013-2014 by Łukasz Mierzwa
     :contact: l.mierzwa@gmail.com
 """
 
@@ -95,9 +95,9 @@ class BuildPackageForm(CrispyForm):
 
     submit_label = 'Build'
     submit_icon_class = 'fa fa-cog'
-    layout = ['force_fresh']
+    layout = ['build_type']
 
-    force_fresh = forms.BooleanField(required=False)
+    build_type = forms.ChoiceField(required=False)
 
 
 class StopApplicationForm(CrispyForm):
