@@ -35,7 +35,7 @@ from upaas import processes
 from upaas_admin.apps.servers.models import RouterServer, BackendServer
 from upaas_admin.apps.scheduler.models import ApplicationRunPlan
 from upaas_admin.apps.applications.exceptions import UnpackError
-from upaas_admin.apps.scheduler.base import select_best_backends
+from upaas_admin.apps.scheduler.base import Scheduler
 from upaas_admin.apps.tasks.constants import TaskStatus
 from upaas_admin.apps.tasks.models import Task
 from upaas_admin.apps.applications.constants import (
@@ -199,10 +199,8 @@ class Package(Document):
         except (AttributeError, KeyError):
             pass
 
-        run_plan = self.application.run_plan
-
         max_memory = backend_conf.workers_max
-        max_memory *= run_plan.memory_per_worker
+        max_memory *= self.application.run_plan.memory_per_worker
         max_memory *= 1024 * 1024
 
         variables = {
@@ -217,8 +215,9 @@ class Package(Document):
             'pkg_id': self.safe_id,
             'max_workers': backend_conf.workers_max,
             'max_memory': max_memory,
-            'memory_per_worker': run_plan.memory_per_worker,
-            'max_log_size': run_plan.max_log_size * 1024 * 1024,
+            'memory_per_worker': self.application.run_plan.memory_per_worker,
+            'max_log_size':
+            self.application.run_plan.max_log_size * 1024 * 1024,
         }
 
         if config.apps.graphite.carbon:
@@ -333,11 +332,12 @@ class Package(Document):
         options.append('\n# starting subscriptions block')
         for router in RouterServer.objects(is_enabled=True):
             options.append('subscribe2 = server=%s:%d,key=%s' % (
-                router.private_ip, router.subscription_port,
+                router.subscription_ip, router.subscription_port,
                 self.application.system_domain))
             for domain in self.application.custom_domains:
                 options.append('subscribe2 = server=%s:%d,key=%s' % (
-                    router.private_ip, router.subscription_port, domain.name))
+                    router.subscription_ip, router.subscription_port,
+                    domain.name))
 
         options.append('\n')
         return options
@@ -428,6 +428,10 @@ class ApplicationDomain(Document):
     name = StringField(required=True, unique=True, min_length=4, max_length=64)
     validated = BooleanField()
 
+    meta = {
+        'indexes': ['application']
+    }
+
     @property
     def safe_id(self):
         return str(self.id)
@@ -459,7 +463,8 @@ class ApplicationFlag(Document):
     meta = {
         'indexes': [
             {'fields': ['name', 'application'], 'unique': True},
-            # TODO add indexes after profiling
+            {'fields': ['name']},
+            {'fields': ['pending']},
         ],
         'ordering': ['-date_created'],
     }
@@ -480,6 +485,7 @@ class Application(Document):
     current_package = ReferenceField(Package, dbref=False, required=False)
     packages = ListField(ReferenceField(Package, dbref=False,
                                         reverse_delete_rule=NULLIFY))
+    run_plan = ReferenceField('ApplicationRunPlan', dbref=False)
 
     _default_manager = QuerySetManager()
 
@@ -554,13 +560,6 @@ class Application(Document):
             return sorted(list(utils.supported_versions(
                 self.upaas_config, self.metadata_config).keys()), reverse=True)
 
-    @property
-    def run_plan(self):
-        """
-        Application run plan if it is present, None otherwise.
-        """
-        return ApplicationRunPlan.objects(application=self).first()
-
     @property
     def can_start(self):
         """
@@ -624,10 +623,6 @@ class Application(Document):
         """
         return "upaas-app-id=%s" % self.safe_id
 
-    @property
-    def router_ip_list(self):
-        return [r.public_ip for r in RouterServer.objects(is_enabled=True)]
-
     def get_absolute_url(self):
         return reverse('app_details', args=[self.safe_id])
 
@@ -646,21 +641,19 @@ class Application(Document):
 
     def start_application(self):
         if self.current_package:
-            run_plan = self.run_plan
-            if not run_plan:
+            if not self.run_plan:
                 log.error("Trying to start '%s' without run plan" % self.name)
                 return
 
-            backends = select_best_backends(run_plan,
-                                            package=self.current_package)
+            scheduler = Scheduler()
+            backends = scheduler.find_backends(self.run_plan)
             if not backends:
                 log.error(_("Can't start '{name}', no backend "
                             "available").format(name=self.name))
-                run_plan.delete()
+                self.run_plan.delete()
                 return
 
-            run_plan.backends = backends
-            run_plan.save()
+            self.run_plan.update(set__backends=backends)
             ApplicationFlag.objects(
                 application=self, name=IsStartingFlag.name).update_one(
                     set__pending_backends=[b.backend for b in backends],
@@ -705,10 +698,9 @@ class Application(Document):
     def update_application(self):
         if self.run_plan:
 
-            run_plan = self.run_plan
-
-            current_backends = [bc.backend for bc in run_plan.backends]
-            new_backends = select_best_backends(run_plan)
+            current_backends = [bc.backend for bc in self.run_plan.backends]
+            scheduler = Scheduler()
+            new_backends = scheduler.find_backends(self.run_plan)
             if not new_backends:
                 log.error(_("Can't update '{name}', no backend "
                             "available").format(name=self.name))
@@ -718,9 +710,9 @@ class Application(Document):
             for backend_conf in new_backends:
                 if backend_conf.backend in current_backends:
                     # replace backend settings with updated version
-                    run_plan.update(
+                    self.run_plan.update(
                         pull__backends__backend=backend_conf.backend)
-                    run_plan.update(push__backends=backend_conf)
+                    self.run_plan.update(push__backends=backend_conf)
                     updated_backends.append(backend_conf.backend)
                 else:
                     # add backend to run plan if not already there
