@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 """
-    :copyright: Copyright 2013 by Łukasz Mierzwa
+    :copyright: Copyright 2013-2014 by Łukasz Mierzwa
     :contact: l.mierzwa@gmail.com
 """
 
@@ -11,17 +11,14 @@ import hmac
 import uuid
 import hashlib
 import logging
-from datetime import datetime, timedelta
 
 from mongoengine.queryset import QuerySetManager
+from mongoengine.django.auth import User as MongoUser
 from mongoengine.fields import StringField
 from mongoengine import signals, Q
 
 from upaas_admin.apps.scheduler.models import UserLimits, ApplicationRunPlan
-from upaas_admin.apps.applications.models import Application
-from upaas_admin.apps.tasks.models import Task
-from upaas_admin.apps.tasks.constants import ACTIVE_TASK_STATUSES
-from upaas_admin.common.hacks.mongoengine_auth import User as MongoUser
+from upaas_admin.apps.applications.models import Application, Task
 
 
 log = logging.getLogger(__name__)
@@ -48,8 +45,8 @@ class User(MongoUser):
         apikey = None
         while apikey is None and User.objects(apikey=apikey) not in [None, []]:
             log.debug("Trying to generate unique API key")
-            apikey = hmac.new(
-                str(uuid.uuid4()), digestmod=hashlib.sha1).hexdigest()
+            apikey = hmac.new(uuid.uuid4().bytes,
+                              digestmod=hashlib.sha1).hexdigest()
         return apikey
 
     @classmethod
@@ -104,12 +101,10 @@ class User(MongoUser):
         """
         List of all tasks for this application.
         """
-        return Task.find('ApplicationTask', application__in=self.applications)
+        return Task.objects(application__in=self.applications)
 
-    @property
-    def recent_tasks(self):
-        return self.tasks.filter(
-            Q(status__in=ACTIVE_TASK_STATUSES) |
-            Q(date_finished__gte=datetime.now() - timedelta(seconds=3600)))
+    @staticmethod
+    def has_usable_password():
+        return True
 
 signals.pre_save.connect(User.pre_save, sender=User)
