@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 """
-    :copyright: Copyright 2013 by Łukasz Mierzwa
+    :copyright: Copyright 2013-2014 by Łukasz Mierzwa
     :contact: l.mierzwa@gmail.com
 """
 
@@ -83,6 +83,7 @@ class UPaaSConfig(base.Config):
                                                        min_value=16),
                 "packages_per_app": base.IntegerEntry(required=True,
                                                       min_value=2),
+                "max_log_size": base.IntegerEntry(required=True, min_value=1),
             }
         },
         "admin": {
@@ -90,6 +91,15 @@ class UPaaSConfig(base.Config):
             "loglevel": base.StringEntry(default='info'),
             "debug": base.BooleanEntry(default=False),
             "domains": base.ListEntry(value_type=unicode),
+            "smtp": {
+                "host": base.StringEntry(default='localhost', required=True),
+                "port": base.IntegerEntry(default=25, required=True),
+                "tls": base.BooleanEntry(default=False),
+                "username": base.StringEntry(),
+                "password": base.StringEntry(),
+                "sender": base.StringEntry(default='no-reply@localhost',
+                                           required=True),
+            }
         },
         "interpreters": base.WildcardEntry(),
     }
