@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 """
-    :copyright: Copyright 2013 by Łukasz Mierzwa
+    :copyright: Copyright 2013-2014 by Łukasz Mierzwa
     :contact: l.mierzwa@gmail.com
 """
 
@@ -21,10 +21,14 @@ TEMPLATE_LOADERS = (
 
 LOGGING['handlers']['console']['level'] = 'DEBUG'
 
+LOGGING['formatters']['standard']['format'] = "[pid:%(process)s] " \
+                                              "%(levelname)s [%(name)s:" \
+                                              "%(lineno)s] %(message)s"
 
-#==============================================================================
+
+# =============================================================================
 # django-pipeline
-#==============================================================================
+# =============================================================================
 
 PIPELINE_ENABLED = False
 
